api.authentication.v1 package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1 package

## Subpackages

- api.authentication.v1.ldap package
  - Submodules
  - api.authentication.v1.ldap.ldap_authenticate module
  - Module contents
- api.authentication.v1.password package
  - Submodules
  - api.authentication.v1.password.password_authenticate module
  - Module contents
- api.authentication.v1.radius package
  - Submodules
  - api.authentication.v1.radius.radius_authenticate module
  - Module contents
- api.authentication.v1.signature package
  - Submodules
  - api.authentication.v1.signature.signature_authenticate module
  - Module contents
- api.authentication.v1.sms package
  - Submodules
  - api.authentication.v1.sms.sms_authenticate module
  - Module contents
- api.authentication.v1.user package
  - Submodules
  - api.authentication.v1.user.user_apikey module
  - Module contents

## Submodules

## api.authentication.v1.apikey module

Autogenerated API

`api.authentication.v1.apikey.` `authenticate`(apikey: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user session using API key (PUBLIC) Requires password authentication to be enabled on the server, and for the userUse /methods to check which authentication methods are available on the server.

  Use this operation to create a session to last across multiple requests.This might be useful for some legacy operations which require a web session, or for performance reasons if performing a large number of requests.

  End session using /logout For one-shot requests, use Argus-API-Key header.

  Return type: | `dict`

`api.authentication.v1.apikey.` `initiate`(password: str = None, description: str = None, validSources: <function list at 0x10c8658c8> = None, expirationDays: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new apikey for current user (PUBLIC)

  Return type: | `dict`
  Parameters: | password (str) – User password to verify this request description (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* validSources (list) – Client IP/CIDR networks which the api key will be valid for. expirationDays (int) – Requested expiration days, 0 means unlimited. Default is 3 months. If user does not have permissions to specify expiration period, an error will be returned.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 334, “limit”: 341, “responseCode”: 200, “count”: 968, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “His sound similar wall song drug year current.”, “messageTemplate”: “Baby Mr approach writer quality.”, “field”: “Agency federal possible head.”, “parameter”: {}, “timestamp”: 1154278647}], “currentPage”: 226, “size”: 2}

`api.authentication.v1.apikey.` `list`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List current user apikeys (PUBLIC)

  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 141, “limit”: 593, “responseCode”: 200, “count”: 713, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Agreement nothing usually season.”, “messageTemplate”: “Travel ahead politics event.”, “field”: “Art president that would.”, “parameter”: {}, “timestamp”: 1018737964}], “currentPage”: 432, “size”: 113}

`api.authentication.v1.apikey.` `renew`(keyID: int, password: str = None, expirationDays: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Renew an apikey for current user (PUBLIC) API keys have limited validity. This operationallows the user to renew a key, to allow it to remain functional for a new validity period.

  Return type: | `dict`

`api.authentication.v1.apikey.` `revoke`(keyID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Revoke an apikey from current user (PUBLIC)

  Return type: | `dict`
  Parameters: | keyID (int) – Key ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 945, “limit”: 843, “responseCode”: 200, “count”: 394, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Relate interesting ok offer attack account eat.”, “messageTemplate”: “Support citizen determine often.”, “field”: “Data toward project happy realize operation entire.”, “parameter”: {}, “timestamp”: 1369505864}], “currentPage”: 581, “size”: 249}

## api.authentication.v1.constrain module

Autogenerated API

`api.authentication.v1.constrain.` `constrain`(customerID: list = None, functionID: list = None, function: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request a constrained session (PUBLIC) This operation will spawn a new user session, where the active userspermissions are constrained to the specified subset of the active users permissions.In addition to returning the constrained session token, the new session will be set as cookies, overwriting any existing session cookies.

  Return type: | `dict`

## api.authentication.v1.impersonate module

Autogenerated API

`api.authentication.v1.impersonate.` `constrain`(userName: str = None, domain: str = None, customerID: list = None, functionID: list = None, function: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request an impersonated session (TEST) This operation will spawn a new user session impersonating another user, where the active users permissions are constrained to the intersection of the impersonating and impersonated users, and limited to the subset optionally specified in the request. In addition to returning the impersonating session token, the new session will be set as cookies, overwriting any existing session cookies.

  Return type: | `dict`

## api.authentication.v1.logout module

Autogenerated API

`api.authentication.v1.logout.` `logout`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Invalidate current user session (PUBLIC)

  Returns: | {}

## api.authentication.v1.methods module

Autogenerated API

`api.authentication.v1.methods.` `get_methods`(argus_last_method: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List authentication methods available on this server (PUBLIC) Returns a list of authentication methods available on the server. The last successful authentication performed on the client will be returned asmetaData.lastUsedAuthenticationMethod

  Return type: | `dict`

## api.authentication.v1.session module

Autogenerated API

`api.authentication.v1.session.` `get_session`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get session information of current user (DEV)

  Raises: | AuthenticationFailedException – on 401
  Returns: | {“sessionKey”: “Partner exist contain perhaps action at.”, “securityLevel”: “EXTERNAL”, “createdTimestamp”: 1510553489, “timestamp”: 1435223220, “authenticationMethod”: “SIGNATURE”}

## api.authentication.v1.totp module

Autogenerated API

`api.authentication.v1.totp.` `authenticate`(userName: str = None, domain: str = None, password: str = None, tokenCode: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user session using TOTP authentication (PUBLIC) Requires TOTP authentication to be enabled on the server, and for the user. Use /methods to check which authentication methods are available on the server.

  This is a 2-factor authentication method. The authentication request should carrythe username, the static password, and the TOTP token.. Tokens cannot be reused. Attempting to authenticate with a previously used token,will cause a challenge. Wait for the tokencode to change and resubmit.

  Return type: | `dict`

`api.authentication.v1.totp.` `initialize`(password: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new TOTP generator for the user (PUBLIC) TOTP authentication requires a TOTP generator to be set up for the user.

  This operation allows the user to set up a TOTP generator. This requires TOTP authentication to be enabled for the user. The TOTP initialization request also requires the user to providethe static Argus password for verification. The TOTP generator code retrieved cannot be retrieved again. It should be added directly to the TOTP generator, and should not be stored elsewhere.

  After initializing, the new TOTP generator is in a pending state, and will notbe active until it is verified using the verification operation.

  Return type: | `dict`

`api.authentication.v1.totp.` `revoke`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Revoke the current TOTP generator for the user (PUBLIC) This operation invalidates the current generator config for the user. The user will need to re-initialize the TOTP generator to be able to log inusing TOTP.

  > raises AuthenticationFailedException:
  > | on 401
  > raises ValidationErrorException:
  > | on 412
  > raises AccessDeniedException:
  > | on 403
  > raises NotFoundException:
  > | on 404
  > returns: | {“offset”: 747, “limit”: 440, “responseCode”: 200, “count”: 56, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Material across those check card soldier.”, “messageTemplate”: “Address suffer trade surface opportunity oil.”, “field”: “Take support address figure especially.”, “parameter”: {}, “timestamp”: 703002969}], “currentPage”: 302, “size”: 506}

`api.authentication.v1.totp.` `verify`(cookie: str = None, verificationCode: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Verify the pending TOTP generator for the user (PUBLIC) This operation will activate the pending generator.The verification request should contain the cookie returned from theinitialize command, as well as the current generated code.

  If the user has an existing generator, successfully validatingthe pending generator will invalidate the existing generator.

  Return type: | `dict`

## Module contents